# Kvaser


Data / Data science:
---------------------
- **timeseries.plot** : plot methods for time series data
- **desc** : Simple summary statistics for NumPy/Pandas objects
- **dag** : Simulation from structural equation models / generalized linear models

Utilities:
---------------------
- **blob_storage** : tool for working with azure blob storage
- **reload** : easy reloading of modules
- **mproc** : CLI tool for multiple file processing
